.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Добро пожаловать в учебное пособие Sage!
========================================
Sage — это бесплатное и свободно распространяемое математическое программное
обеспечение с открытыми исходными кодами для исследовательской работы и обучения
в самых различных областях включая алгебру, геометрию, теорию чисел,
криптографию, численные вычисления и другие. Как модель разработки Sage, так и
условия его распространения и использования выбраны в соответствии с принципами
открытой и совместной работы: мы собираем машину, а не переизобретаем колесо.
Одной из основных целей Sage является создание доступной, бесплатной и открытой
альтернативы Maple, Matematica, Magma и MATLAB.


Настоящий документ распространяется по лицензии
`Creative Commons Attribution-Share Alike 3.0`__.

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   introduction
   tour
   interactive_shell
   interfaces
   programming
   sagetex
   afterword
   appendix
   bibliography

